@@ -892,26 +892,18 @@ void Helper::renderCheckBoxBackground(QPainter *painter,
 
     const auto radius = Metrics::CheckBox_Radius;
 
-    switch (state) {
-    case CheckOff:
-        painter->setBrush(palette.button().color().darker(sunken ? radioCheckSunkenDarkeningFactor : 100));
-        painter->drawRoundedRect(frameRect, radius, radius);
-        break;
+    painter->setBrush(palette.button().color().darker(sunken ? radioCheckSunkenDarkeningFactor : 100));
+    painter->drawRoundedRect(frameRect, radius, radius);
 
-    case CheckPartial:
-    case CheckOn:
-        painter->setBrush(transparent.darker(sunken ? radioCheckSunkenDarkeningFactor : 100));
-        painter->drawRoundedRect(frameRect, radius, radius);
-        break;
-
-    case CheckAnimated:
-        painter->setBrush(palette.button().color().darker(sunken ? radioCheckSunkenDarkeningFactor : 100));
-        painter->drawRoundedRect(frameRect, radius, radius);
-        painter->setBrush(transparent);
-        painter->setOpacity(animation);
-        painter->drawRoundedRect(frameRect, radius, radius);
-        break;
+    if (state == CheckOff) {
+        return;
     }
+
+    painter->setBrush(transparent);
+    if (state == CheckAnimated) {
+        painter->setOpacity(animation);
+    }
+    painter->drawRoundedRect(frameRect, radius, radius);
 }
 
 //______________________________________________________________________________
@@ -1050,23 +1042,18 @@ void Helper::renderRadioButtonBackground(QPainter *painter,
     }
     painter->setPen(QPen(penBrush, PenWidth::Frame));
 
-    switch (state) {
-    case RadioOff:
-        painter->setBrush(palette.button().color().darker(sunken ? radioCheckSunkenDarkeningFactor : 100));
-        painter->drawEllipse(frameRect);
-        break;
-    case RadioOn:
-        painter->setBrush(transparent.darker(sunken ? radioCheckSunkenDarkeningFactor : 100));
-        painter->drawEllipse(frameRect);
-        break;
-    case RadioAnimated:
-        painter->setBrush(palette.button().color().darker(sunken ? radioCheckSunkenDarkeningFactor : 100));
-        painter->drawEllipse(frameRect);
-        painter->setBrush(transparent);
-        painter->setOpacity(animation);
-        painter->drawEllipse(frameRect);
-        break;
+    painter->setBrush(palette.button().color().darker(sunken ? radioCheckSunkenDarkeningFactor : 100));
+    painter->drawEllipse(frameRect);
+
+    if (state == RadioOff) {
+        return;
     }
+
+    painter->setBrush(transparent);
+    if (state == RadioAnimated) {
+        painter->setOpacity(animation);
+    }
+    painter->drawEllipse(frameRect);
 }
 
 //______________________________________________________________________________
